@@ -21,6 +21,9 @@ NB: Repeating groups must be defined as a tuple thus
 
 Created on 4 Mar Sep 2021
 
+While the NMEA 0183 © protocol is proprietary, the information here
+has been collated from public domain sources.
+
 :author: semuadmin
 """
 
